@@ -1,5 +1,6 @@
 #define QT_FEATURE_xcb 1
 #define QT_FEATURE_accessibility_atspi_bridge 1
+#define QT_FEATURE_angle_d3d11_qdtd -1
 #define QT_FEATURE_direct2d -1
 #define QT_FEATURE_directfb -1
 #define QT_FEATURE_egl 1
@@ -10,6 +11,8 @@
 #define QT_FEATURE_eglfs_egldevice 1
 #define QT_FEATURE_eglfs_gbm 1
 #define QT_FEATURE_eglfs_mali -1
+#define QT_FEATURE_eglfs_openwfd -1
+#define QT_FEATURE_eglfs_rcar -1
 #define QT_FEATURE_eglfs_viv -1
 #define QT_FEATURE_eglfs_viv_wl -1
 #define QT_FEATURE_evdev -1
